Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(455)

Unified Diff: chrome/browser/browsing_data/browsing_data_local_storage_helper.h

Issue 2403713002: Add suborigin logic to url::Origin (Closed)
Patch Set: Fix unit test Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/browsing_data/browsing_data_local_storage_helper.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/browsing_data/browsing_data_local_storage_helper.h
diff --git a/chrome/browser/browsing_data/browsing_data_local_storage_helper.h b/chrome/browser/browsing_data/browsing_data_local_storage_helper.h
index b261e2cf125d98829c60a52d174c661881684cc0..f9c976b15088e695248c6efb4906fe48cde3a1d0 100644
--- a/chrome/browser/browsing_data/browsing_data_local_storage_helper.h
+++ b/chrome/browser/browsing_data/browsing_data_local_storage_helper.h
@@ -48,8 +48,8 @@ class BrowsingDataLocalStorageHelper
// callback. This must be called only in the UI thread.
virtual void StartFetching(const FetchCallback& callback);
- // Deletes the local storage for the |origin|.
- virtual void DeleteOrigin(const GURL& origin);
+ // Deletes the local storage for the |origin_url|.
+ virtual void DeleteOrigin(const GURL& origin_url);
protected:
friend class base::RefCounted<BrowsingDataLocalStorageHelper>;
@@ -71,7 +71,7 @@ class CannedBrowsingDataLocalStorageHelper
// Add a local storage to the set of canned local storages that is returned
// by this helper.
- void AddLocalStorage(const GURL& origin);
+ void AddLocalStorage(const GURL& origin_url);
// Clear the list of canned local storages.
void Reset();
@@ -87,7 +87,7 @@ class CannedBrowsingDataLocalStorageHelper
// BrowsingDataLocalStorageHelper implementation.
void StartFetching(const FetchCallback& callback) override;
- void DeleteOrigin(const GURL& origin) override;
+ void DeleteOrigin(const GURL& origin_url) override;
private:
~CannedBrowsingDataLocalStorageHelper() override;
« no previous file with comments | « no previous file | chrome/browser/browsing_data/browsing_data_local_storage_helper.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698